// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

//
// condnb_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = MY_condnb_close ( computed, expected, epsilon )
  if (expected==0.0) then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

function flag = MY_condnb_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

[c,y] = condnb_powcond ( 2 , 5 );
MY_condnb_equal ( c , 5 );
MY_condnb_equal ( y , 32 );

// Extremelly bad condition
[c,y] = condnb_powcond ( 1.000000000000001 , 1.e15 );
MY_condnb_close ( y , 2.718281828459043876 , 1 );
MY_condnb_close ( c , 1.e15 , %eps );

// Another one : http://bugzilla.scilab.org/show_bug.cgi?id=4048
[c,y] = condnb_powcond ( 0.9999999999999999 , -18014398509482000 );
MY_condnb_close ( y , 6.05836432903779269 , 1 );
MY_condnb_close ( c , 1.8D+16 , 0.1 );


